package com.develou.shoppinglist.data;

import androidx.lifecycle.LiveData;
import androidx.room.Dao;
import androidx.room.Delete;
import androidx.room.Insert;
import androidx.room.OnConflictStrategy;
import androidx.room.Query;
import androidx.room.Update;

import com.develou.shoppinglist.shoppinglists.ShoppingListForList;
import com.develou.shoppinglist.shoppinglists.ShoppingListId;

import java.util.List;

@Dao
public interface ShoppingListDao {
    @Query("SELECT id, name, is_favorite FROM shopping_list")
    LiveData<List<ShoppingListForList>> getAll();

    @Query("SELECT * FROM shopping_list WHERE id = :id LIMIT 1")
    LiveData<ShoppingList> getShoppingList(String id);

    @Query("SELECT id, name, is_favorite FROM shopping_list WHERE category IN(:categories)")
    LiveData<List<ShoppingListForList>> getShoppingListsByCategories(List<String> categories);

    @Insert(onConflict = OnConflictStrategy.IGNORE)
    void insert(ShoppingList shoppingList);

    @Insert(onConflict = OnConflictStrategy.IGNORE, entity = ShoppingList.class)
    void partialInsert(ShoppingListInsert shoppingList);

    @Insert(onConflict = OnConflictStrategy.IGNORE, entity = ShoppingList.class)
    void insertShoppingLists(List<ShoppingListInsert> lists);

    @Update(entity = ShoppingList.class)
    void markFavorite(ShoppingListFavorite shoppingList);

    @Delete(entity = ShoppingList.class)
    void deleteShoppingList(ShoppingListId id);

    @Query("DELETE FROM shopping_list")
    void deleteAllShoppingLists();
}
