package com.develou.shoppinglist.shoppinglists;

import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.CheckBox;
import android.widget.ImageView;
import android.widget.TextView;

import androidx.annotation.NonNull;
import androidx.recyclerview.widget.RecyclerView;

import com.develou.shoppinglist.R;

import java.util.List;

public class ShoppingListAdapter
        extends RecyclerView.Adapter<ShoppingListAdapter.ShoppingListViewHolder> {

    private List<ShoppingListForList> mShoppingLists;
    private ItemListener mItemListener;

    @NonNull
    @Override
    public ShoppingListViewHolder onCreateViewHolder(@NonNull ViewGroup parent, int viewType) {
        return new ShoppingListViewHolder(
                LayoutInflater.from(parent.getContext())
                        .inflate(R.layout.shopping_list_item, parent, false)
        );
    }

    @Override
    public void onBindViewHolder(@NonNull ShoppingListViewHolder holder, int position) {
        ShoppingListForList item = mShoppingLists.get(position);
        holder.bind(item);
    }

    @Override
    public int getItemCount() {
        return mShoppingLists == null ? 0 : mShoppingLists.size();
    }

    public void setItems(List<ShoppingListForList> items) {
        mShoppingLists = items;
        notifyDataSetChanged();
    }

    public void setItemListener(ItemListener listener) {
        mItemListener = listener;
    }

    interface ItemListener {
        void onClick(ShoppingListForList shoppingList);

        void onFavoriteIconClicked(ShoppingListForList shoppingList);

        void onDeleteIconClicked(ShoppingListForList shoppingList);
    }

    public class ShoppingListViewHolder extends RecyclerView.ViewHolder {
        private final TextView mNameText;
        private final CheckBox mFavoriteButton;
        private final ImageView mDeleteButton;

        public ShoppingListViewHolder(@NonNull View itemView) {
            super(itemView);
            mNameText = itemView.findViewById(R.id.name);
            mFavoriteButton = itemView.findViewById(R.id.favorite_button);
            mDeleteButton = itemView.findViewById(R.id.delete_button);

            // Setear eventos
            mFavoriteButton.setOnClickListener(this::manageEvents);
            mDeleteButton.setOnClickListener(this::manageEvents);
            itemView.setOnClickListener(this::manageEvents);
        }

        private void manageEvents(View view) {
            if (mItemListener != null) {
                ShoppingListForList clickedItem = mShoppingLists.get(getAdapterPosition());

                // Manejar evento de click en Favorito
                if (view.getId() == R.id.favorite_button) {
                    mItemListener.onFavoriteIconClicked(clickedItem);
                    return;
                } else if (view.getId() == R.id.delete_button) {
                    mItemListener.onDeleteIconClicked(clickedItem);
                    return;
                }

                mItemListener.onClick(clickedItem);
            }
        }

        public void bind(ShoppingListForList item) {
            mNameText.setText(item.name);
            mFavoriteButton.setChecked(item.favorite);
        }
    }
}
